wsp-balsa: Common modelling tools
=================================

``wsp-balsa`` is a collection of functions and tools for Python to facilitate travel demand forecasting applications and analyses. It is designed to work the the "scientific stack" of Python, namely NumPy, Pandas, and Matplotlib; which are optimized for speed and usability. The package mostly consists of standalone functions; for input/output, for analysis, etc.; as well as a few lightweight class-based data structures for specific applications.

The import statement for the ``wsp-balsa`` package is as follows:

.. code-block:: python

   import balsa

.. toctree::
   :maxdepth: 3
   :caption: Contents

   routines/index
   logging/index
